ajdmom.itos\_mom
================

.. automodule:: ajdmom.itos_mom

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      c
      coef_poly
      int_et
      int_mIEI_IEII
      moment_IEI_IEII
      recursive_IEI_IEII
      t_mul_t0
   
   

   
   
   

   
   
   



